@@ -35,8 +35,8 @@ public:
 
     static void setupEngine();
     void setupLoader();
-    Grantlee::Context createContext(const QVariantHash &data = QVariantHash(), const QByteArray &applicationDomain = QByteArray());
-    QString errorTemplate(const QString &reason, const QString &templateName, const Grantlee::Template &errorTemplate);
+    Q_REQUIRED_RESULT Grantlee::Context createContext(const QVariantHash &data = QVariantHash(), const QByteArray &applicationDomain = QByteArray());
+    Q_REQUIRED_RESULT QString errorTemplate(const QString &reason, const QString &templateName, const Grantlee::Template &errorTemplate);
 
     QStringList displayExtraVariables;
     QString themeFileName;
